@@ -10,6 +10,9 @@ fn main() -> io::Result<()> {
     )?;
     println!(r#"I see your favourite day is "{}"."#, day);
 
+    let number: usize = uquery::parsable_with_default("Whats your favourite number?", 7)?;
+    println!("Hello {} lover", number);
+
     let age: u8 = uquery::parsable("How old are you?")?;
     println!("Hello {} year old.", age);
 
